@@ -1,6 +1,5 @@
 from cffi import FFI
 import numpy as np
-import sys
 
 """PySoundFile is an audio library based on libsndfile, CFFI and Numpy
 
@@ -222,7 +221,7 @@ class SoundFile(object):
     """
 
     def __init__(self, name, sample_rate=0, channels=0, format=0,
-                 mode=read_write_mode):
+                 mode=read_mode):
         """Open a new SoundFile.
 
         If a file is only opened in read_mode or in read_write_mode,
@@ -262,9 +261,18 @@ class SoundFile(object):
 
     def __del__(self):
         # be sure to flush data to disk before closing the file
-        _snd.sf_write_sync(self._file)
-        err = _snd.sf_close(self._file)
-        self._handle_error_number(err)
+        if self._file:
+            _snd.sf_write_sync(self._file)
+            err = _snd.sf_close(self._file)
+            self._handle_error_number(err)
+            self._file = None
+
+    def __enter__(self):
+        return self
+
+    def __exit__(self, type, value, tb):
+        # flush remaining data to disk and close file
+        self.__del__()
 
     def _handle_error(self):
         # this checks the error flag of the SNDFILE* structure
